 
#ifndef _NESSUSC_GLOBALS_H
#define _NESSUSC_GLOBALS_H
extern struct arglist * MainDialog;
extern char * Alt_rcfile;
extern struct plugin_filter Filter;

extern int F_show_pixmaps;
extern int F_quiet_mode;
extern int ListOnly;

#ifdef _WIN32
# include "globals.w32"
/* #define _NO_PIES */
#endif /* _WIN32 */

# define HANDLE int

#endif
